@@ -10,6 +10,7 @@ logger = logging.getLogger(__name__)
 
 hubbase = "http://hub:5000"
 dsbase = urljoin(hubbase, "services/downloadservice/fetch/pnfs/cta.cscs.ch/")
+altdsbase = urljoin(hubbase, "fetch/pnfs/cta.cscs.ch/")
 
 
 def list_dir(url):
@@ -20,7 +21,7 @@ def list_dir(url):
                 params = {'token': os.getenv("JUPYTERHUB_API_TOKEN")},
             )
     try:
-        return [u.replace(dsbase, "") for u in r.json()['urls']]
+        return [u.replace(dsbase, "").replace(altdsbase, "") for u in r.json()['urls']]
     except Exception as e:
         return r.text[:1000]
 
